function y=bsmooth(x,lwin)
%BSMOOTH  Binomial-weighted smoothing.
%
%	bsmooth(x,lwin)
%
%	Returns weighted smoothing of vector [x] over a window of
%	length lwin.  Weighting ratios are determined from the
%	coefficients of Pascal's triangle.  The resulting vector [y]
%	is the same length as [x].

%	Neil Viney --- 4 May 1994

[m,n]=size(x);
y=x;
if n==1
  x=x';
end;
nw=floor((lwin-1)/2);
x=[(1:nw)*NaN,x,(1:nw)*NaN];
b=diag(fliplr(pascal(lwin)))';
for i=1:length(y);
  a=x(i:(i+2*nw));
  jj=find(isfinite(a)==1);
  y(i)=sum(a(jj).*b(jj))/sum(b(jj));
end;
